//*************************************************
// USART 12F
//
// Library for EUSART usage on PIC12F1822/40
// author: Bernardo Giovanni
// http://www.settorezero.com
// date:  12/10/11
//
// PLEASE DON'T REDISTRIBUTE WITHOUT PERMISSION
//
// E' VIETATA LA RIPUBBLICAZIONE SU ALTRI SITI,
// FORUM O ALTRI MEZZI SENZA AUTORIZZAZIONE
// DELL'AUTORE
//
// Prerequisites:
// you must define _XTAL_FREQ macro in the main, expressed as Hz
// ex.: 
// #define _XTAL_FREQ 32000000 // 32MHz
//
// WARNING!
// this library use SYNC=0, BRGH=1 and BRG16=0, so the SPBRG value
// is calculated for those settings. If you want to use different settings
// you must change the SPBRGVAL formula define
//*************************************************

#include <stdio.h>
#include "usart12f.h"

void uart_init()
	{
	RXDTSEL=RXS; // RX alternate pin
	TXCKSEL=TXS; // TX alternate pin
	ANSELA &= (TXM | RXM); // disable analog inputs on interested pins
	SYNC=0; // asynchronous
	SPEN=1; // enable module, this will set TX as output, no RX
	TXEN=1; // enable transmitter
	CREN=1; // enable receiver
	RX_PIN=1; // RX as input
	RX9=0; // 8 bit reception
	TX9D=0; // 8bit transmission
	ADDEN=0; // no addressing
	ABDEN=0; // autobaud disabled
	WUE=0; // normal receiver operation, no wake up
	SCKP=0; // transmit non-inverted data
	BRG16=0; // 8 bit baudrate generator
	BRGH=1; // high speed
		
	SPBRGL=SPBRGVAL & 0xFF;
	SPBRGH=SPBRGVAL << 8;
 
	while(RCIF)
        {
        char Temp;
        Temp = RCREG;
        }
	TXIF=0; // reset transmit interrupt flag
	__delay_ms(10);
	}

void putch(unsigned char byte) 
	{
	/* output one byte */
	while(!TXIF)	/* set when register is empty */
		continue;
	TXREG = byte;
	}

unsigned char getch() 
	{
	/* retrieve one byte */
	while(!RCIF)	/* set when register is not empty */
		continue;
	return RCREG;	
	}

unsigned char getche(void)
	{
	unsigned char c;
	putch(c = getch());
	return c;
	}
	